#[server_function]Expand description
Attribute macro to register a function as an RPC server handler. This macro generates a function that can handle RPC requests with proper type safety and registers it with the server function registry.
#[server_function]Attribute macro to register a function as an RPC server handler. This macro generates a function that can handle RPC requests with proper type safety and registers it with the server function registry.